<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml" xmlns:exsl="http://exslt.org/common" extension-element-prefixes="exsl">

<xsl:include href="rewrite.xsl" />
<xsl:include href="default_access_denied.xsl" />
<xsl:include href="breadcrumbs.xsl" />
<xsl:include href="box.xsl" />
<xsl:include href="avatar.xsl" />

<xsl:template match="urls" />
<xsl:template match="forum" />
<xsl:template match="topic" />
<xsl:template match="logininfo" />

<xsl:template match="posts">

    <xsl:call-template name="breadcrumbs">
        <xsl:with-param name="link1">
            <a href="{$rw_cat}{cat/uri}{$rw_cat_ext}" onclick="return f.selectForumIndex('{cat/uri}')"><xsl:value-of select="cat/title" disable-output-escaping="yes" /></a>
        </xsl:with-param>
        <xsl:with-param name="link2">
            <a href="{$rw_forum}{forum/uri}{$rw_forum_page}0{$rw_forum_ext}" onclick="return f.selectForum('{forum/uri}', 0);"><xsl:value-of select="forum/title" disable-output-escaping="yes" /></a>
        </xsl:with-param>        
    </xsl:call-template>

	<div id="reply_container">&#160;</div>

    <xsl:variable name="menu_links">
        <xsl:if test="forum/id != 0 and topic/id != 0">
            <btn href="javascript:void(0);" onclick="return f.newTopic('{forum/uri}')" icon="{/root/urls/img}btn_icon_new_topic.gif">[L[New Topic]]</btn>
            <xsl:if test="0 = topic/locked">                    
                <btn href="javascript:void(0);" onclick="return f.postReply('{forum/id}','{topic/id}')" icon="{/root/urls/img}btn_icon_reply.gif">[L[Post Reply]]</btn>				
            </xsl:if>   
            <btn href="javascript:void(0);" onclick="return f.flag({topic/id});" icon="{/root/urls/img}btn_icon_flag.gif">[L[Flag/Unflag]]</btn>
            <xsl:if test="1 = /root/logininfo/admin">
                <xsl:if test="0 = topic/locked">
                    <btn href="javascript:void(0);" onclick="return orca_admin.lock('{topic/id}', '{topic/locked}');" icon="{/root/urls/img}btn_icon_unlocked.gif">[L[Lock/Unlock]]</btn>
                </xsl:if>
                <xsl:if test="1 = topic/locked">
                    <btn href="javascript:void(0);" onclick="return orca_admin.lock('{topic/id}', '{topic/locked}');" icon="{/root/urls/img}btn_icon_locked.gif">[L[Lock/Unlock]]</btn>
                </xsl:if>                    
            </xsl:if>                
            <btn href="{$rw_topic}{topic/uri}{$rw_topic_ext}" onclick="" icon="{/root/urls/img}btn_icon_plink.gif">[L[Permalink]]</btn>
            <btn href="{$rw_rss_topic}{topic/uri}{$rw_rss_topic_ext}" onclick="" icon="{/root/urls/img}btn_icon_rss.gif">[L[RSS Feed]]</btn>
        </xsl:if>
    </xsl:variable>

    <xsl:call-template name="box">
        <xsl:with-param name="title"><xsl:value-of select="topic/title" disable-output-escaping="yes" /></xsl:with-param>
        <xsl:with-param name="content">
            <table class="forum_table_list">
                <tr>
                    <th style="width:120px;" class="forum_table_column_first">[L[Author]]</th>
                    <th class="forum_table_column_others">[L[Message]]</th>
                </tr>
                <xsl:apply-templates select="post" />
            </table>
        </xsl:with-param>
        <xsl:with-param name="menu" select="exsl:node-set($menu_links)/*" />
    </xsl:call-template>

	<iframe name="post_actions" width="1" height="1" frameborder="1" style="border:none;">&#160;</iframe>

</xsl:template>

<xsl:template match="force_show_post">
	<xsl:call-template name="post_row_box" />
</xsl:template>

<xsl:template match="post">
	<tr id="post_row_{@id}">
		<xsl:call-template name="post_row_box" />
	</tr>
</xsl:template>

<xsl:template name="post_row_box">
    <xsl:call-template name="post_row_content" />
</xsl:template>

<xsl:template name="post_row_content">
	<xsl:choose>
        <xsl:when test="((points &lt; min_point) or (vote_user_point = -1)) and (0 = @force_show)">
            <td valign="top" class="forum_table_cell_stranger">			
                <div class="forum_stranger"><xsl:value-of select="user/@name" /></div>
			</td>            						    
            <td id="{@id}" valign="top">
			    <xsl:call-template name="post_row_actions" />
            </td>
		</xsl:when>				
		<xsl:otherwise>
			<td valign="top" class="forum_table_cell_user">
                <xsl:if test="string-length(user/avatar) &gt; 0"> 
                    <xsl:call-template name="avatar">
                        <xsl:with-param name="href" select="user/url" />
                        <xsl:with-param name="thumb" select="user/avatar" />
                        <xsl:with-param name="username" select="user/@name" />
                    </xsl:call-template>
				</xsl:if> 
				<xsl:choose>
					<xsl:when test="string-length(user/url) &gt; 0">
						<b><a target="_blank" href="{user/url}" onclick="{user/onclick}"><xsl:value-of select="user/@name" /></a></b>
					</xsl:when>
					<xsl:otherwise>
						<b><xsl:value-of select="user/@name" /></b> 
					</xsl:otherwise>					
				</xsl:choose>
				<br />
                [L[posts:]] <xsl:value-of select="user/@posts" /> <br />
			</td>            						    
            <td id="{@id}" valign="top">

                <xsl:call-template name="post_row_actions" />

                <div class="forum_post_text">
                    <xsl:choose>
                        <xsl:when test="/root/urls/xsl_mode = 'server'">
                            <xsl:value-of select="text" disable-output-escaping="yes" />
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:choose>
                                <xsl:when test="system-property('xsl:vendor')='Transformiix'">
                                    <div id="{@id}_foo" style="display:none;"><xsl:value-of select="text" /></div>
                                    <script type="text/javascript">
                                        var id = '<xsl:value-of select="@id" />';
                                        <![CDATA[
                                        orca_html_decode (id + '_foo', id);
                                        ]]>
                                    </script>
                                </xsl:when>
                                <xsl:when test="system-property('xsl:vendor')='Microsoft'">
                                    <xsl:value-of select="text" disable-output-escaping="yes" />
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="text" disable-output-escaping="yes" />
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:otherwise>
                    </xsl:choose>
                </div>
			</td>

		</xsl:otherwise>
	</xsl:choose>

</xsl:template>

<xsl:template name="post_row_actions">


    <div class="forum_post_actions">
        
        <div id="report_{@id}" class="forum_post_actions_report_button">
            <xsl:choose>
                <xsl:when test="'' = vote_user_point">
                    <a title="[L[report this post]]" href="javascript:void(0);" onclick="f.report({@id}); return f.voteBad({@id});" style="margin-right:3px;"><img style="border:none;" src="{/root/urls/img}report.png" /></a>
                </xsl:when>
                <xsl:otherwise>
                    <a title="[L[report this post]]" href="javascript:void(0);" style="margin-right:3px;"><img style="border:none;" src="{/root/urls/img}report_gray.png" /></a>
                </xsl:otherwise>
            </xsl:choose>
        </div>
        
        <span class="forum_post_actions_when">
            <xsl:value-of select="when" />
        </span>

        <xsl:if test="(allow_del + allow_edit) = 0">
            <span>&#160;</span>
        </xsl:if>
        
        <xsl:if test="allow_del = 1">
            <a style="margin:0 5px 0  5px;" href="javascript:void(0);" onclick="f.deletePost({@id}, {../forum/id}, {../topic/id}, true)">[L[Delete]]</a>
        </xsl:if>

        <xsl:if test="allow_edit = 1">
            <a onclick="f.editPost({@id});" href="javascript:void(0);">[L[Edit]]</a>
        </xsl:if>

        <xsl:if test="(not((points &lt; min_point) or (vote_user_point = -1))) and 0 = ../topic/locked">			
            &#160;<a href="javascript:void(0);" onclick="return f.postReplyWithQuote({../forum/id}, {../topic/id}, {@id});">[L[Quote]]</a>
        </xsl:if>


        <div class="forum_post_actions_rate" id="rate_{@id}">
            <span class="forum_post_actions_rate_text">
                <xsl:if test="((points &lt; min_point) or (vote_user_point = -1))">			
                    [L[post is hidden]] (
                        <xsl:choose>
                            <xsl:when test="1 = @force_show">
                                <a href="javascript:void(0);" onclick="f.hideHiddenPost({@id})">[L[hide post]]</a>
                            </xsl:when>		
                            <xsl:otherwise>							
                                <a href="javascript:void(0);" onclick="f.showHiddenPost({@id})">[L[show post]]</a>
                            </xsl:otherwise>																
                        </xsl:choose>
                        )
                </xsl:if>

                [L[Points:]]
                <span id="points_{@id}"><xsl:value-of select="points" /></span>
                &#160;
                [L[Vote]]
            </span>

            <div class="forum_post_actions_rate_buttons">
                <xsl:choose>
                    <xsl:when test="'' = vote_user_point and user/@name != /root/logininfo/username">
                        <a href="javascript:void(0);" onclick="return f.voteGood({@id});" style="margin-right:3px;"><img class="vote_good" src="{/root/urls/img}vote_good.gif" /></a>
                        <a href="javascript:void(0);" onclick="return f.voteBad({@id});"><img class="vote_bad" src="{/root/urls/img}vote_bad.gif" /></a>
                    </xsl:when>
                    <xsl:otherwise>					
                        <a href="javascript:void(0);" style="margin-right:3px;"><img class="vote_good" src="{/root/urls/img}vote_good_gray.gif" /></a>
                        <a href="javascript:void(0);"><img class="vote_bad" src="{/root/urls/img}vote_bad_gray.gif" /></a>
                    </xsl:otherwise>
                </xsl:choose>					
            </div>
        </div>	

    </div>

</xsl:template>

</xsl:stylesheet>


