<?php

    /***************************************************************************
    *                            Dolphin Smart Community Builder
    *                              -------------------
    *     begin                : Mon Mar 23 2006
    *     copyright            : (C) 2007 BoonEx Group
    *     website              : http://www.boonex.com
    * This file is part of Dolphin - Smart Community Builder
    *
    * Dolphin is free software; you can redistribute it and/or modify it under
    * the terms of the GNU General Public License as published by the
    * Free Software Foundation; either version 2 of the
    * License, or  any later version.
    *
    * Dolphin is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
    * without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    * See the GNU General Public License for more details.
    * You should have received a copy of the GNU General Public License along with Dolphin,
    * see license.txt file; if not, write to marketing@boonex.com
    ***************************************************************************/

    bx_import('BxDolModuleDb');
    bx_import('BxDolModule');

    require_once( BX_DIRECTORY_PATH_PLUGINS . 'Services_JSON.php' );

    /*
     * Shoutbox module by BoonEx
     *
     * This module allow user to send messages that will show on site's home page. 
     * This is default module and Dolphin can not work properly without this module.
     *
     *
     *
     * Profile's Wall:
     * no wall events
     *
     *
     *
     * Spy:
     * no spy events
     *
     *
     *
     * Memberships/ACL:
     * use shoutbox - BX_USE_SHOUTBOX
     *
     *
     *
     * Service methods:
     *
     * Generate shoutbox window. 
     * @see BxShoutBoxModule::serviceGetShoutBox();
     * BxDolService::call('shoutbox', 'get_shoutbox');
     *
     * Alerts:
     *
     * no alerts here;
     *
     */
    class BxShoutBoxModule extends BxDolModule 
    {
        // contain some module information ;
        var $aModuleInfo;

        // contain path for current module;
        var $sPathToModule;

        // contain logged member's Id;
        var $iMemberId;

        // contain all used templates
        var $aUsedTemplates = array();

        // contain some smiles codes;
        var $aSmiles = array();

        /**
    	 * Class constructor ;
         *
         * @param   : $aModule (array) - contain some information about this module;
         *                  [ id ]           - (integer) module's  id ;
         *                  [ title ]        - (string)  module's  title ;
         *                  [ vendor ]       - (string)  module's  vendor ;
         *                  [ path ]         - (string)  path to this module ;
         *                  [ uri ]          - (string)  this module's URI ;
         *                  [ class_prefix ] - (string)  this module's php classes file prefix ;
         *                  [ db_prefix ]    - (string)  this module's Db tables prefix ;
         *                  [ date ]         - (string)  this module's date installation ;
    	 */
    	function BxShoutBoxModule(&$aModule) 
        {
            parent::BxDolModule($aModule);

            // prepare the location link ;
            $this -> sPathToModule  = BX_DOL_URL_ROOT . $this -> _oConfig -> getBaseUri();
            $this -> aModuleInfo    = $aModule;

            $this -> iMemberId = getLoggedId();

            $this -> aUsedTemplates = array(
                'message'           => 'message.html',
                'visitor_message'   => 'visitor_message.html',
            );

            $this -> aSmiles = array(
                ':arrow:'  => 'icon_arrow.gif',
                ':D'       => 'icon_biggrin.gif',
                ':-D'      => 'icon_biggrin.gif',
                ':grin:'   => 'icon_biggrin.gif',
                ':?'       => 'icon_confused.gif',
                ':-?'      => 'icon_confused.gif',
                '???:'     => 'icon_confused.gif',
                '8)'       => 'icon_cool.gif',
                '8-)'      => 'icon_cool.gif',
                ':cool:'   => 'icon_cool.gif',
                ':cry:'    => 'icon_cry.gif',
                ':shock:'  => 'icon_eek.gif',
                ':evil:'   => 'icon_evil.gif',
                ':!:'      => 'icon_exclaim.gif',
                ':idea:'   => 'icon_idea.gif',
                ':lol:'    => 'icon_lol.gif',
                ':x'       => 'icon_mad.gif',
                ':-x'      => 'icon_mad.gif',
                ':mad:'    => 'icon_mad.gif',
                ':mrgreen' => 'icon_mrgreen.gif',
                ':|'       => 'icon_neutral.gif',
                ':-|'      => 'icon_neutral.gif',
                ':neutral' => 'icon_neutral.gif',
                ':?:'      => 'icon_question.gif',
                ':P'       => 'icon_razz.gif',
                ':-P'      => 'icon_razz.gif',
                ':razz:'   => 'icon_razz.gif',
                ':oops:'   => 'icon_redface.gif',
                ':roll:'   => 'icon_rolleyes.gif',
                ':('       => 'icon_sad.gif',
                ':-('      => 'icon_sad.gif',
                ':sad:'    => 'icon_sad.gif',
                ':)'       => 'icon_smile.gif',
                ':-)'      => 'icon_smile.gif',
                ':smile:'  => 'icon_smile.gif',
                ':o'       => 'icon_surprised.gif',
                ':-o'      => 'icon_surprised.gif',
                ':eek:'    => 'icon_surprised.gif',
                ':twisted' => 'icon_twisted.gif',
                ':wink:'   => 'icon_wink.gif',
                ';)'       => 'icon_wink.gif',
                ';-)'      => 'icon_wink.gif',
            );
        }

        /**
         * Function will write new message;
         */
        function actionWriteMessage()
        {
            if( $this -> isShoutBoxAlowed($this -> iMemberId, true) ) {

                $sMessage = ( isset($_POST['message']) )
                    ? strip_tags( trim($_POST['message']) )
                    : '';

                if($sMessage) {

                	// procces smiles;
                    if($this -> _oConfig -> bProccesSmiles) {
                        $sMessage = $this -> proccesSmiles($sMessage);
                    }

                    // create message;
                    $this -> _oDb -> writeMessage($sMessage, $this -> iMemberId);

                    // delete some messages;
                    $iMessagesCount = $this -> _oDb -> getMessagesCount();
                    if($iMessagesCount > $this -> _oConfig -> iAllowedMessagesCount) {
                        $this -> _oDb -> deleteMessages($iMessagesCount - $this -> _oConfig -> iAllowedMessagesCount);
                    }
                }
                else {
                    echo _t('_bx_shoutbox_message_empty');
                }
            }
        }

        /**
         * Function will return all latest messages;
         *
         * @param  : $iLastMessageId (integer) - last message's Id;
         * @return : (text) - in JSON format;
         */
        function actionGetMessages($iLastMessageId = 0)
        {
        	$iLastMessageId		= (int) $iLastMessageId;

            $oJsonParser        = new Services_JSON();
            $sMessages          = $this -> getLastMessages($iLastMessageId);
            $iLastMessageId     = $this -> _oDb -> getLastMessageId();

            $aRetArray = array(
                'messages'          => $sMessages,
                'last_message_id'   => $iLastMessageId,
            );

            echo $oJsonParser -> encode($aRetArray);
        }

        /**
         * Function will generate the shoutbox's admin page ;
         *
         * @return : (text) - Html presentation data ;
         */
        function actionAdministration()
        {
        	$GLOBALS['iAdminPage'] = 1;

            if( !isAdmin() ) {
                header('location: ' . BX_DOL_URL_ROOT);
            }

            $aLanguageKeys = array(
                'settings' => _t('_bx_shoutbox_settings'),
            );

            // try to define globals category number;
            $iId = $this-> _oDb -> getSettingsCategory('shoutbox_update_time');
            if(!$iId) {
                $sContent = MsgBox( _t('_Empty') );
            }
            else {
                bx_import('BxDolAdminSettings');

                $mixedResult = '';
                if(isset($_POST['save']) && isset($_POST['cat'])) {
                    $oSettings = new BxDolAdminSettings($iId);
                    $mixedResult = $oSettings -> saveChanges($_POST);
                }

                $oSettings = new BxDolAdminSettings($iId);
                $sResult = $oSettings->getForm();

                if($mixedResult !== true && !empty($mixedResult))
                    $sResult = $mixedResult . $sResult;

                $sCssStyles = $this -> _oTemplate -> addCss( 'forms_adv.css', true );

                $sContent = $sCssStyles . $GLOBALS['oAdmTemplate'] 
                        -> parseHtmlByName( 'design_box_content.html', array('content' => $sResult) );
            }

            $this -> _oTemplate-> pageCodeAdminStart();
            echo $this -> _oTemplate -> adminBlock ($sContent, $aLanguageKeys['settings']);
            $this -> _oTemplate->pageCodeAdmin ( _t('_bx_shoutbox_module') );
        }

        /**
         * Function will generate the shoutbox window;
         */
        function serviceGetShoutBox()
        {
            $sOutputCode = '';

            $aLanguageKeys = array(
                'send'                  => _t('_bx_shoutbox_send'),
                'message_here'          => _t('_bx_shoutbox_message_here'),
                'message_empty_message' => _t('_bx_shoutbox_enter_message'),
            );

            $iLastMessageId  = $this -> _oDb -> getLastMessageId();
            $sMessagesList   = $this -> getLastMessages();

            $sOutputCode     = $this -> _oTemplate -> addCss('shoutbox.css', true);
            $sOutputCode    .= $this -> _oTemplate -> addJS('shoutbox.js');

            $aForm = array (
                'params'=> array('remove_form' => true),

                'inputs' => array (
                    'messages'   => array(
                        'type'    => 'custom',
                        'content' => '<div class="shoutbox_wrapper">' . $sMessagesList . '</div>',
                        'colspan' => true,
                    ),

                    'message'   => array(
                        'type'      => 'text',
                        'name'      => 'message',
                        'colspan'   => true,
                        'attrs' => array(
                            'onkeyup' => "if(typeof oShoutBox != 'undefined'){oShoutBox.sendMessage(event, this)} return false",
                            'id'      => 'shoutbox_msg_field',
                        ),
                    ),
                ),
            );

            $sOutputCode .= <<<INIT
                <script type="text/javascript">
                    var oShoutBox = new BxShoutBox();
                    oShoutBox.oMessages.empty_message = '{$aLanguageKeys['message_empty_message']}';
                    oShoutBox.sPageReceiver  = '{$this -> sPathToModule}';
                    oShoutBox.iUpdateTime    = {$this -> _oConfig -> iUpdateTime};
                    oShoutBox.iLastMessageId = {$iLastMessageId};

                    $('#shoutbox_msg_field').parent().addClass('shoutbox_send_field');

                    var elShoutbox = $('.' + oShoutBox.sMessagesContainer);
                    if(elShoutbox) {
                        var iBoxPadding = 20;
                        var iShoutboxParentWidth = elShoutbox.parents('.form_advanced_wrapper').width();
                        elShoutbox.css('width', iShoutboxParentWidth - iBoxPadding);
                    }

                    oShoutBox.scrollContent();

                    $(document).ready(function () {
                        oShoutBox.getMessages();
                    });
                </script>
INIT;

            $oForm       = &new BxTemplFormView($aForm);
            $sOutputCode = '<div class="dbContentHtml">' . $oForm -> getCode() . $sOutputCode . '</div>';

            echo $sOutputCode;
        }

        /**
         * Function will generate list of last messages;
         *
         * @param  :  $iLastId (integer) - last message's Id;
         * @return : (text) - html presentation data;
         */
        function getLastMessages($iLastId = 0)
        {
            global $oFunctions;

            $iLastId		= (int) $iLastId;
            $sOutputCode    = '';
            $aMessages      = $this -> _oDb -> getMessages($iLastId);

            $aLanguageKeys  = array(
                'by'        => _t('_bx_shoutbox_by'),
                'visitor'   => _t('_Visitor'),
            );

            // procces recived data;
            if($aMessages) {
                foreach($aMessages as $iKey => $aItems)
                {
                    $sMemberIcon = null;
                    $bProfileDefined = $aItems['OwnerID'] && getProfileInfo($aItems['OwnerID'])
                        ? true
                        : false;

                    // define member's nickname;
                    if($bProfileDefined) {
                        $sNickName   = getNickName($aItems['OwnerID']);
                        $sLink       = getProfileLink($aItems['OwnerID']);
                        $sMemberIcon = $oFunctions -> getMemberIcon($aItems['OwnerID']);
                    }
                    else {
                        $sLink      = 'javascript:void(0)';
                        $sNickName  = $aLanguageKeys['visitor'];
                    }

                    $aTemplateKeys = array
                    (
                        'owner_icon'    => $sMemberIcon,
                        'message'       => $aItems['Message'],
                        'by'            => $aLanguageKeys['by'],
                        'owner_nick'    => $sNickName,
                        'date'          => getLocaleDate( strtotime($aItems['Date']), BX_DOL_LOCALE_DATE), 
                        'owner_link'    => $sLink,
                    );

                    // define needed tamplate;
                    $sTemplate = ($bProfileDefined) 
                        ? $this -> aUsedTemplates['message'] 
                        : $this -> aUsedTemplates['visitor_message'];

                    $sOutputCode .=  $this -> _oTemplate -> parseHtmlByName($sTemplate, $aTemplateKeys);
                }
            }

            return $sOutputCode;
        }

        /**
         * Function will procces smile's codes;
         *
         * @param  : $sText (string) ;
         * @return : (string) - proccesed text; 
         */
        function proccesSmiles($sText)
        {
            foreach($this -> aSmiles as $sCode => $sImgPath)
            {
                $sImgPath = $this -> _oTemplate -> getIconUrl($sImgPath);
                $sText = str_replace($sCode, "<img border=\"0\" alt=\"{$sCode}\" src=\"{$sImgPath}\" />", $sText);
            }

            return $sText;
        }

        /**
         * Function will check membership level for current type if users;
         *
         * @param : $iMemberId (integer) - member's Id;
         * @param : $isPerformAction (boolean) - if isset this parameter that function will amplify the old action's value;
         */
        function isShoutBoxAlowed($iMemberId, $isPerformAction = false) 
        {
          $this -> _defineActions();
          $aCheck = checkAction($iMemberId, BX_USE_SHOUTBOX, $isPerformAction);
          return $aCheck[CHECK_ACTION_RESULT] == CHECK_ACTION_RESULT_ALLOWED;
        }

        function _defineActions() 
        {
            defineMembershipActions( array('use shoutbox') );
        }
    }